@@ -613,7 +613,7 @@ def _read_filter_save(input_dict):
     read_filter_save(**input_dict)
 
 
-def _find_all_images(input_path, zstep=None):
+def _find_all_images(input_path, output_path, zstep=None):
     """Find all images with a supported file extension within a directory and all its subdirectories
 
     Parameters
@@ -645,6 +645,12 @@ def _find_all_images(input_path, zstep=None):
                 else:
                     img_paths.append(p)
         elif p.is_dir():
+            rel_path = p.relative_to(input_path)
+            o = output_path.joinpath(rel_path)
+            if not o.exists():
+                o.mkdir(parents=True)
+
+
             img_paths.extend(_find_all_images(p, zstep))
     return img_paths
 
@@ -694,6 +700,11 @@ def batch_filter(input_path, output_path, workers, chunks, sigma, auto_mode, lev
         Flag for converting to 16-bit
     """
 
+    print('testing version')
+
+
+
+
     error_path = os.path.join(output_path, 'error_log.txt')
     if os.path.exists(error_path):
         os.remove(error_path)
@@ -701,7 +712,7 @@ def batch_filter(input_path, output_path, workers, chunks, sigma, auto_mode, lev
     if workers == 0:
         workers = multiprocessing.cpu_count()
     print('Looking for images in {}...'.format(input_path))
-    img_paths = _find_all_images(input_path, zstep)
+    img_paths = _find_all_images(input_path, output_path, zstep)
     print('Found {} compatible images'.format(len(img_paths)))
     print('Setting up {} workers...'.format(workers))
     args = []
